@@ -582,3 +582,33 @@ chop :: ([a] -> (b, [a])) -> [a] -> [b]
 chop _ [] = []
 chop f as = b : chop f as'
   where (b, as') = f as
+
+-- | Divides up an input list into a set of sublists, according to 'n' and 'm'
+--   input specifications you provide. Each sublist will have 'n' items, and the
+--   start of each sublist will be offset by 'm' items from the previous one.
+--
+-- > divvy 5 5 [1..20] == [[1,2,3,4,5],[6,7,8,9,10],[11,12,13,14,15],[16,17,18,19,20]]
+--
+--   In the case where a source list's trailing elements do no fill an entire
+--   sublist, those trailing elements will be dropped.
+--
+-- > divvy 5 2 [1..10] == [[1,2,3,4,5],[3,4,5,6,7],[5,6,7,8,9]]
+--
+--   As an example, you can generate a moving average over a list of prices:
+-- 
+-- > type Prices = [Float]
+-- > type AveragePrices = [Float]
+-- > 
+-- > average :: [Float] -> Float
+-- > average xs = sum xs / (fromIntegral $ length xs)
+-- > 
+-- > simpleMovingAverage :: Prices -> AveragePrices
+-- > simpleMovingAverage priceList =
+-- >   map average divvyedPrices
+-- >     where divvyedPrices = divvy 20 1 priceList
+
+divvy :: Int -> Int -> [a] -> [[a]]
+divvy _ _ [] = []
+divvy n m lst = filter (\ws -> (n == length ws)) choppedl
+  where choppedl = chop (\xs -> (take n xs , drop m xs)) lst
+
